<?php

namespace EventPortal\Domain\Table;

use EventPortal\Concerns\HasWhen;
use EventPortal\Domain\Component\Button;

class GroupedActions
{
    use HasWhen;

    /** @var string */
    public $label;

    /** @var EventPortal\Domain\User\Models\User */
    public $user;

    /** @var array */
    public $actions = [];

    public function __construct(string $label)
    {
        $this->label = $label;
        $this->user = auth()->user();
    }

    public static function make(string $label): self
    {
        return new self($label);
    }

    public function actions(array $actions): self
    {
        foreach ($actions as $action) {
            $this->actions[] = $action;
        }

        return $this;
    }

    public function addIfUserHasPermission(string $permission, callable $callable): self
    {
        if ($this->user && $this->user->hasPermissionTo($permission)) {
            $this->add($callable);
        }

        return $this;
    }

    private function add(callable $callable): self
    {
        $this->actions[] = $callable() instanceof Button ? $callable()->toArray() : $callable();

        return $this;
    }
}
